#!/usr/bin/env python

"""
Command option processing and other utilities for compiling and testing
programs.
"""

import micropython

def parse_optimisations(args):

    "Parse 'args' for optimisation flags."

    if "-omax" in args:
        requested_optimisations = micropython.Program.supported_optimisations
    else:
        requested_optimisations = []
        for arg in args:
            if arg.startswith("-o"):
                for arg_part in arg[2:].split(","):
                    requested_optimisations.append(arg_part)

    return requested_optimisations

def program(filename, path, requested_optimisations, verbose=0):

    """
    Return the program object for the program specified by the given 'filename',
    module search 'path' and 'requested_optimisations'.
    """

    i = micropython.Importer(path, verbose, requested_optimisations)
    p = micropython.Program(i, requested_optimisations)

    i.load_from_file("lib/builtins.py", "__builtins__")

    if filename is not None:
        i.load_from_file(filename)

    return p

# Convenience functions.

def get_program(filename, path, args):

    """
    Return the program object for the program specified by the given 'filename',
    module search 'path' and command 'args'.
    """

    requested_optimisations = parse_optimisations(args)
    return program(filename, path, requested_optimisations, "-v" in args)

# vim: tabstop=4 expandtab shiftwidth=4
